summaryrefslogtreecommitdiffstats
path: root/common/rfb/CMsgHandler.h
diff options
context:
space:
mode:
authorPierre Ossman <ossman@cendio.se>2009-03-20 13:02:50 +0000
committerPierre Ossman <ossman@cendio.se>2009-03-20 13:02:50 +0000
commit49f8822a8fd1a1d4a21451bc5d3566e4eb15942e (patch)
tree0e78a3768fba9c9c59695cdabe128517b019157c /common/rfb/CMsgHandler.h
parentc5e25601d923169c30b656246ac503451f04e638 (diff)
downloadtigervnc-49f8822a8fd1a1d4a21451bc5d3566e4eb15942e.tar.gz
tigervnc-49f8822a8fd1a1d4a21451bc5d3566e4eb15942e.zip
Minimal client side support for the extended desktop size protocol.
git-svn-id: svn://svn.code.sf.net/p/tigervnc/code/trunk@3699 3789f03b-4d11-0410-bbf8-ca57d06f2519
Diffstat (limited to 'common/rfb/CMsgHandler.h')
-rw-r--r--common/rfb/CMsgHandler.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/common/rfb/CMsgHandler.h b/common/rfb/CMsgHandler.h
index 188963a4..49d407ad 100644
--- a/common/rfb/CMsgHandler.h
+++ b/common/rfb/CMsgHandler.h
@@ -1,4 +1,5 @@
/* Copyright (C) 2002-2005 RealVNC Ltd. All Rights Reserved.
+ * Copyright 2009 Pierre Ossman for Cendio AB
*
* This is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -38,11 +39,12 @@ namespace rfb {
// The following methods are called as corresponding messages are read. A
// derived class should override these methods as desired. Note that for
// the setDesktopSize(), setPixelFormat() and setName() methods, a derived
// class should call on to CMsgHandler's methods to set the members of cp
// appropriately.
virtual void setDesktopSize(int w, int h);
+ virtual void setExtendedDesktopSize(int reason, int result, int w, int h);
virtual void setCursor(int width, int height, const Point& hotspot,
void* data, void* mask);
virtual void setPixelFormat(const PixelFormat& pf);
@@ -38,11 +39,12 @@ namespace rfb {
// The following methods are called as corresponding messages are read. A
// derived class should override these methods as desired. Note that for
- // the setDesktopSize(), setPixelFormat() and setName() methods, a derived
- // class should call on to CMsgHandler's methods to set the members of cp
- // appropriately.
+ // the setDesktopSize(), setExtendedDesktopSize(), setPixelFormat() and
+ // setName() methods, a derived class should call on to CMsgHandler's
+ // methods to set the members of cp appropriately.
virtual void setDesktopSize(int w, int h);